ApplicationConfig class

Annotations
  • @freezed

Constructors

ApplicationConfig({String? enviroment, String? primaryColor, String? primarySecondColor, bool? multiColor, String? btnColor, })
factory
ApplicationConfig.fromJson(Map<String, dynamic> json)
factory

Properties

btnColor → String?
no setterinherited
copyWith → $ApplicationConfigCopyWith<ApplicationConfig>
no setterinherited
enviroment → String?
no setterinherited
hashCode → int
The hash code for this object.
no setterinherited
no setterinherited
multiColor → bool?
no setterinherited
primaryColor → String?
no setterinherited
primarySecondColor → String?
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited