StatementBuilder class

Implementers
Available extensions

Constructors

StatementBuilder()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
statements → List<Statement>
final

Methods

alterTable(String tableName) → AlterTableBuilder

Available on StatementBuilder, provided by the AlterTable extension

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toSql() → String
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited